import React, { CSSProperties, FC, ReactNode } from 'react';
import { LoaderProps } from '../Loaders';
import './Button.css';
export interface ButtonProps {
    /**
     * Ghost buttons are generally bordered by a very thin line,
     * while the internal section consists of plain text.
     * They most often appear as Call to Action (CTA) buttons and offer a clean look
     *
     * <@default=`false`>
     */
    isGhost?: boolean;
    /**
     * <@default=`false`>
     */
    isDisabled?: boolean;
    /**
     * <@default=`false`>
     */
    isLoading?: boolean;
    /**
     * If true, button width will become 100%
     *
     * <@default=`false`>
     */
    isFull?: boolean;
    className?: string;
    /**
     * <@default=`{}`>
     */
    style?: CSSProperties;
    children?: ReactNode;
    /**
     * <@default=`'button'`>
     */
    type?: 'button' | 'submit' | 'reset';
    /**
     * <@default=`'rect'`>
     */
    variant?: 'rect' | 'circle' | 'pill' | 'text' | 'icon';
    /**
     * <@default=`'medium'`>
     */
    size?: 'small' | 'medium' | 'large';
    /**
     * <@default=`button`>
     */
    element?: 'button' | 'span';
    /**
     * A Ztopia Loader either in function form (`MusicLoader`) or element form (`<MusicLoader />`)
     *
     * <@default=`null`>
     */
    loader?: ReactNode | FC<LoaderProps>;
    onClick?: (e: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void;
    onMouseEnter?: (e: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void;
    onMouseLeave?: (e: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void;
}
export declare const Button: React.NamedExoticComponent<ButtonProps>;
