import React from 'react';
export interface Axis {
    accessor?: string;
    color?: string;
}
export declare type Accessor = string | number | ((datum: any) => string | number | [number, number] | null);
export interface Legend {
    /**
     * <@default=`50`>
     */
    height?: number;
    variant?: 'plainline' | 'line' | 'square' | 'rect' | 'circle' | 'cross' | 'diamond' | 'star' | 'triangle' | 'wye';
}
export interface Shape {
    stroke?: string;
    fill?: string;
    accessor: Accessor;
}
/**
 * https://github.com/d3/d3-shape#curves
 */
export declare type D3Interpolation = 'basis' | 'basisClosed' | 'basisOpen' | 'linear' | 'linearClosed' | 'natural' | 'monotoneX' | 'monotoneY' | 'monotone' | 'step' | 'stepBefore' | 'stepAfter';
export interface Line extends Shape {
    /**
     * <@default=`'monotone'`>
     */
    variant?: D3Interpolation;
}
export interface Area extends Shape {
    /**
     * <@default=`'monotone'`>
     */
    variant?: D3Interpolation;
}
export interface Bar extends Shape {
    width?: number;
}
export interface ChartProps {
    /**
     * <@default=`800`>
     */
    width?: number;
    /**
     * <@default=`400`>
     */
    height?: number;
    /**
     * Chart skeleton color
     *
     * <@default=`'#cbd0d8'`>
     */
    color?: string;
    data: any[];
    /**
     * <@default=`{}`>
     */
    xAxis?: Axis;
    /**
     * <@default=`{}`>
     */
    yAxis?: Axis;
    legend?: Legend;
    lines?: Line[];
    areas?: Area[];
    bars?: Bar[];
}
export declare const Chart: React.NamedExoticComponent<ChartProps>;
