import React, { CSSProperties, ReactNode } from 'react';
import { ActionMeta, OptionsType, OptionTypeBase, StylesConfig } from 'react-select';
import './Select.css';
export declare type SelectOption = {
    label: ReactNode;
    value: string;
};
export declare type SelectValue = SelectOption | SelectOption[] | null;
export interface SelectProps<OptionType extends OptionTypeBase = SelectOption, IsMulti extends boolean = false> {
    /**
     * Enable isMulti selection
     *
     * <@default=`false`>
     */
    isMulti?: boolean;
    /**
     * <@default=`false`>
     *
     */
    isSearchable?: boolean;
    /**
     * <@default=`false`>
     */
    isLoading?: boolean;
    /**
     * <@default=`true`>
     */
    isClearable?: boolean;
    /**
     * <@default=`false`>
     */
    isDisabled?: boolean;
    /**
     * <@default=`200`>
     */
    maxMenuHeight?: number;
    /**
     * <@default=`undefined`>
     */
    maxSelectedOptions?: number;
    name?: string;
    label?: string;
    error?: string;
    /**
     * <@default=`'Select...'`>
     */
    placeholder?: string;
    className?: string;
    variant?: 'material' | 'rect';
    defaultValue?: SelectValue;
    value?: SelectValue;
    options?: OptionsType<OptionType>;
    style?: CSSProperties;
    styles?: StylesConfig<OptionType, IsMulti>;
    /**
     * <@default=`() => 'No options'`>
     */
    renderNoOptionMessage?: (obj: {
        inputValue: string;
    }) => ReactNode;
    /**
     * <@default=`() => 'Cannot select more than N options'`>
     */
    renderMaxSelectedOptionsReachedMessage?: (obj: {
        inputValue: string;
    }) => ReactNode;
    onChange?: (newSelectValue: SelectValue, actionMeta: ActionMeta<OptionType>) => void;
}
export declare const Select: React.NamedExoticComponent<SelectProps<SelectOption, false>>;
